@@ -1,16 +1,29 @@
+# copyright 2006-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# contact http://www.logilab.fr/ -- mailto:contact@logilab.fr
+#
+# This file is part of logilab-mtconverter.
+#
+# logilab-mtconverter is free software: you can redistribute it and/or modify it
+# under the terms of the GNU Lesser General Public License as published by the
+# Free Software Foundation, either version 2.1 of the License, or (at your
+# option) any later version.
+#
+# logilab-mtconverter is distributed in the hope that it will be useful, but
+# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
+# for more details.
+#
+# You should have received a copy of the GNU Lesser General Public License along
+# with logilab-mtconverter. If not, see <http://www.gnu.org/licenses/>.
 """Mime type conversion package.
 
-:copyright:
   2006-2008 `LOGILAB S.A. <http://www.logilab.fr>`_ (Paris, FRANCE),
   all rights reserved.
 
-:contact:
   http://www.logilab.org/project/rql --
   mailto:python-projects@logilab.org
 
-:license:
-  `General Public License version 2
-  <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>`_
+  `Lesser General Public License version 2`
 """
 __docformat__ = "restructuredtext en"
 
@@ -20,8 +33,9 @@ import locale
 import mimetypes
 import re
 import string
-from StringIO import StringIO
 import htmlentitydefs
+import codecs
+from StringIO import StringIO
 
 try:
     import chardet
@@ -43,7 +57,7 @@ UNICODE_POLICY = 'strict'
 
 CHARSET_DECL_RGX = re.compile('(?:charset|(?:(?:en)?coding))[=:\s"\']*([^\s"\']*)',
                               re.I | re.S | re.U)
-CHARSET_DECL_SEARCH_SIZE = 1024
+CHARSET_DECL_SEARCH_SIZE = 512
 
 CHARDET_MIN_SIZE = 20
 CHARDET_CONFIDENCE_THRESHOLD = 0.75
@@ -66,7 +80,13 @@ def guess_encoding(buffer, fallbackencoding=None):
     # try to get a character set declaration
     m = CHARSET_DECL_RGX.search(buffer[:CHARSET_DECL_SEARCH_SIZE])
     if m is not None:
-        return m.group(1)
+        guessed = m.group(1)
+        try:
+            # ensure encoding is known by python
+            codecs.lookup(guessed)
+            return guessed
+        except LookupError:
+            pass
     if buffer.lstrip().startswith('<?xml'):
         # xml files with no encoding declaration default to UTF-8
         return 'UTF-8'
