@@ -1,4 +1,21 @@
 # -*- coding: utf-8 -*-
+# copyright 2006-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# contact http://www.logilab.fr/ -- mailto:contact@logilab.fr
+#
+# This file is part of logilab-mtconverter.
+#
+# logilab-mtconverter is free software: you can redistribute it and/or modify it
+# under the terms of the GNU Lesser General Public License as published by the
+# Free Software Foundation, either version 2.1 of the License, or (at your
+# option) any later version.
+#
+# logilab-mtconverter is distributed in the hope that it will be useful, but
+# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
+# for more details.
+#
+# You should have received a copy of the GNU Lesser General Public License along
+# with logilab-mtconverter. If not, see <http://www.gnu.org/licenses/>.
 from logilab.common.testlib import TestCase, unittest_main
 
 import locale
@@ -81,6 +98,17 @@ class GuessEncodingTC(TestCase):
 </html>'''
         self.assertEquals(guess_encoding(data), 'latin1')
 
+    def test_bad_detection(self):
+        data = '''class SchemaViewer(object):
+    """return an ureport layout for some part of a schema"""
+    def __init__(self, req=None, encoding=None):
+'''
+        # ascii detected by chardet
+        try:
+            import chardet
+            self.assertEquals(guess_encoding(data), 'ascii')
+        except ImportError:
+            self.assertEquals(guess_encoding(data), DEFAULT_ENCODING)
 
 class GuessMimetymeAndEncodingTC(TestCase):
     def test_base(self):
